@@ -1,9 +1,6 @@
 /* © 2008 David Given.
  * WordGrinder is licensed under the MIT open source license. See the COPYING
  * file in this distribution for the full text.
- *
- * $Id: globals.h 159 2009-12-13 13:11:03Z dtrg $
- * $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/c/globals.h $
  */
 
 #ifndef GLOBALS_H
@@ -20,9 +17,10 @@
 /* --- Emulation issues -------------------------------------------------- */
 
 #if defined EMULATED_WCWIDTH
-extern int wcwidth(int c);
+extern int emu_wcwidth(int c);
 #else
 #include <wchar.h>
+#define emu_wcwidth(c) wcwidth(c)
 #endif
 
 extern int main(int argc, const char* argv[]);
@@ -62,9 +60,9 @@ extern void screen_deinit(void);
 
 extern void word_init(void);
 
-/* --- Bitmask management ------------------------------------------------ */
+/* --- Zipfile management ------------------------------------------------ */
 
-extern void bit_init(void);
+extern void zip_init(void);
 
 /* --- General utilities ------------------------------------------------- */
 
