@@ -1,16 +1,13 @@
 -- © 2008 David Given.
--- WordGrinder is licensed under the BSD open source license. See the COPYING
+-- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
---
--- $Id: browser.lua 121 2008-09-07 15:35:27Z dtrg $
--- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/browser.lua $
 
 local min = min
 local max = max
 local int = math.floor
 local string_rep = string.rep
 local Write = wg.write
-local Goto = wg.goto
+local GotoXY = wg.gotoxy
 local SetNormal = wg.setnormal
 local SetBold = wg.setbold
 local SetUnderline = wg.setunderline
