@@ -1,18 +1,19 @@
 -- © 2008 David Given.
--- WordGrinder is licensed under the BSD open source license. See the COPYING
+-- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
---
--- $Id: text.lua 121 2008-09-07 15:35:27Z dtrg $
--- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/export/text.lua $
 
-local function callback(fp, document)
+local function callback(writer, document)
 	return ExportFileUsingCallbacks(document,
 	{
 		prologue = function()
 		end,
 		
+		rawtext = function(s)
+			writer(s)
+		end,
+		
 		text = function(s)
-			fp:write(s)
+			writer(s)
 		end,
 		
 		notext = function(s)
@@ -40,7 +41,7 @@ local function callback(fp, document)
 		end,		
 		
 		paragraph_end = function(style)
-			fp:write('\n')
+			writer('\n')
 		end,
 		
 		epilogue = function()
