@@ -1,14 +1,11 @@
 -- © 2008 David Given.
 -- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
---
--- $Id: menu.lua 159 2009-12-13 13:11:03Z dtrg $
--- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/menu.lua $
 
 local Write = wg.write
 local ClearToEOL = wg.cleartoeol
 local GetChar = wg.getchar
-local Goto = wg.goto
+local GotoXY = wg.gotoxy
 local SetBold = wg.setbold
 local SetReverse = wg.setreverse
 local SetNormal = wg.setnormal
@@ -81,12 +78,14 @@ local ParagraphStylesMenu = addmenu("Paragraph Styles", {})
 
 local ImportMenu = addmenu("Import new document",
 {
+	{"FIodt",  "O", "Import ODT file...",        nil,         Cmd.ImportODTFile},
 	{"FIhtml", "H", "Import HTML file...",       nil,         Cmd.ImportHTMLFile},
 	{"FItxt",  "T", "Import text file...",       nil,         Cmd.ImportTextFile},
 })
 
 local ExportMenu = addmenu("Export current document",
 {
+	{"FEodt",  "O", "Export to ODT...",          nil,         Cmd.ExportODTFile},
 	{"FEhtml", "H", "Export to HTML...",         nil,         Cmd.ExportHTMLFile},
 	{"FEtxt",  "T", "Export to plain text...",   nil,         Cmd.ExportTextFile},
 	{"FEtex",  "L", "Export to LaTeX...",        nil,         Cmd.ExportLatexFile},
@@ -248,7 +247,7 @@ MenuClass = {
 			
 			SetNormal()
 		end
-		Goto(ScreenWidth-1, ScreenHeight-1)
+		GotoXY(ScreenWidth-1, ScreenHeight-1)
 		
 		DrawStatusLine("^V rebinds a menu item; ^X unbinds it; ^R resets all bindings to default.")
 	end,
@@ -287,6 +286,8 @@ MenuClass = {
 					end
 				elseif (c == "KEY_LEFT") then
 					return nil
+				elseif (c == "KEY_ESCAPE") then
+					return nil
 				elseif (c == "KEY_^X") then
 					local item = menu[n]
 					if (type(item) ~= "string") then
