@@ -1,13 +1,10 @@
 -- © 2008 David Given.
 -- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
---
--- $Id: redraw.lua 159 2009-12-13 13:11:03Z dtrg $
--- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/redraw.lua $
 
 local int = math.floor
 local Write = wg.write
-local Goto = wg.goto
+local GotoXY = wg.gotoxy
 local ClearArea = wg.cleararea
 local SetNormal = wg.setnormal
 local SetBold = wg.setbold
@@ -102,8 +99,8 @@ local function redrawstatus()
 end
 		
 local topmarker = {
-	"     ╲╱          ╲╱          ╲╱          ╲╱          ╲╱     ",
-	"▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔"
+	"     ▲          ▲          ▲          ▲          ▲     ",
+	"▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔"
 }
 local topmarkerwidth = GetStringWidth(topmarker[1])
 
@@ -121,8 +118,8 @@ local function drawtopmarker(y)
 end
 
 local bottommarker = {
-	"▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁",
-	"     ╱╲          ╱╲          ╱╲          ╱╲          ╱╲     ",
+	"▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁",
+	"     ▼          ▼          ▼          ▼          ▼     ",
 }
 local bottommarkerwidth = GetStringWidth(bottommarker[1])
 
@@ -158,7 +155,7 @@ function RedrawScreen()
 
 	do
 		local word = paragraph[Document.cw]
-		Goto(margin + word.x + word:getXOffsetOfChar(Document.co) +
+		GotoXY(margin + word.x + word:getXOffsetOfChar(Document.co) +
 			(paragraph.style.indent or 0), cy - 1)	
 	end
 	
